==> intelligen-0.12.18.tar.gz: intelligen-0.12.18/setup.py <==
#!/usr/bin/env python

"""The setup script."""

import io
from os import path as op
from setuptools import find_packages
from numpy.distutils.core import Extension, setup
import sys

with open('README.md') as readme_file:
    readme = readme_file.read()

here = op.abspath(op.dirname(__file__))

# get the dependencies and installs
with io.open(op.join(here, "requirements.txt"), encoding="utf-8") as f:
    all_reqs = f.read().split("\n")

install_requires = [x.strip() for x in all_reqs if "git+" not in x]
dependency_links = [x.strip().replace("git+", "") for x in all_reqs if "git+" not in x]

requirements = [ ]

setup_requirements = [ ]

test_requirements = [ ]

erf_extension = Extension(name='intelligen.fortran.functions',
                          sources=['intelligen/fortran/erf.f', 'intelligen/fortran/erf.pyf'],
                          extra_compile_args=['/d2FH4-'] if sys.platform == 'win32' else [])

setup(
    author="Diego Bouchet",
    author_email='diegobouchet88@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="This is a Python package for math and artificial intelligence tools",
    install_requires=install_requires,
    dependency_links=dependency_links,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    keywords='intelligen',
    name='intelligen',
    packages=find_packages(include=['intelligen', 'intelligen.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/Bouchet07/intelligen',
    version='0.12.18',
    zip_safe=False,
    ext_modules=[erf_extension],
)

==> intelligen-0.12.19.tar.gz: intelligen-0.12.19/setup.py <==
#!/usr/bin/env python

"""The setup script."""

import io
from os import path as op
from setuptools import find_packages
from numpy.distutils.core import Extension, setup
import sys

with open('README.md') as readme_file:
    readme = readme_file.read()

here = op.abspath(op.dirname(__file__))

# get the dependencies and installs
with io.open(op.join(here, "requirements.txt"), encoding="utf-8") as f:
    all_reqs = f.read().split("\n")

install_requires = [x.strip() for x in all_reqs if "git+" not in x]
dependency_links = [x.strip().replace("git+", "") for x in all_reqs if "git+" not in x]

requirements = [ ]

setup_requirements = [ ]

test_requirements = [ ]

erf_extension = Extension(name='intelligen.fortran.functions',
                          sources=['intelligen/fortran/erf.f', 'intelligen/fortran/erf.pyf'],
                          extra_link_args=["-static", "-static-libgfortran", "-static-libgcc"])
                          #extra_compile_args=['/d2FH4-'] if sys.platform == 'win32' else [])

setup(
    author="Diego Bouchet",
    author_email='diegobouchet88@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="This is a Python package for math and artificial intelligence tools",
    install_requires=install_requires,
    dependency_links=dependency_links,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    keywords='intelligen',
    name='intelligen',
    packages=find_packages(include=['intelligen', 'intelligen.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/Bouchet07/intelligen',
    version='0.12.19',
    zip_safe=False,
    ext_modules=[erf_extension],
)
